abacusai.regenerate_llm_external_application — AbacusAI documentation

# abacusai.regenerate_llm_external_application

## Classes

`RegenerateLlmExternalApplication` | An external application that specifies an LLM user can regenerate with in RouteLLM.

## Module Contents

class abacusai.regenerate_llm_external_application.RegenerateLlmExternalApplication(client, name=None, externalApplicationId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An external application that specifies an LLM user can regenerate with in RouteLLM.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The external name of the LLM.

    - externalApplicationId (str) – The unique identifier of the external application.

  name
  external_application_id
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict